function dlgstruct = udtGetContainerWidgetBase(type,name,tag)
%udtGetContainerWidgetBase Dynamic Dialog block helper function.
%
%   udtGetContainerWidgetBase(type,name,tag,prop)
%   Returns a MATLAB structure for use with Dynamic Dialogs
%   The structure has several common fields filled out:
% 
%    type: Type
%    name: Name
%    tag:  Tag
%    

% Copyright 2003-2010 The MathWorks, Inc.

narginchk(3,3);

dlgstruct.Type = type;
dlgstruct.Name = name;
dlgstruct.Tag = tag;

